"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _fs = require("fs");
function _classPrivateMethodInitSpec(obj, privateSet) { _checkPrivateRedeclaration(obj, privateSet); privateSet.add(obj); }
function _checkPrivateRedeclaration(obj, privateCollection) { if (privateCollection.has(obj)) { throw new TypeError("Cannot initialize the same private elements twice on an object"); } }
function _classPrivateMethodGet(receiver, privateSet, fn) { if (!privateSet.has(receiver)) { throw new TypeError("attempted to get private field on non-instance"); } return fn; }
var _getLockFilePath = /*#__PURE__*/new WeakSet();
class FileMutex {
  constructor(directory, lockFileName, email, authFile, fileDeletionTimeoutConfig) {
    _classPrivateMethodInitSpec(this, _getLockFilePath);
    this.directory = directory;
    this.lockFileName = lockFileName + ".lock";
    this.email = email;
    this.authFile = authFile;
    this.fileDeletionTimeout = fileDeletionTimeoutConfig.timeout;
    this.createDirectoryIfNotExist();
    this.lockFilePath = _classPrivateMethodGet(this, _getLockFilePath, _getLockFilePath2).call(this);
  }
  async acquire() {
    if ((0, _fs.existsSync)(this.authFile)) {
      console.log(`${this.email} Cookie file exists. Loading cookies...`);
      return;
    }
    return new Promise((resolve, reject) => {
      if (!(0, _fs.existsSync)(this.lockFilePath)) {
        (0, _fs.writeFileSync)(this.lockFilePath, 'locked');
        console.log(`Lock file created: ${this.lockFilePath}`);
        return resolve();
      }
      const timeout = setTimeout(() => {
        watcher.close();
        reject(new Error('Watch timeout exceeded'));
      }, this.fileDeletionTimeout);
      const watcher = (0, _fs.watch)(this.directory, (eventType, filename) => {
        try {
          if (eventType === 'rename' && filename === this.lockFileName) {
            clearTimeout(timeout);
            console.log(`Lock file deleted! Proceeding...`);
            watcher.close();
            resolve();
          }
        } catch (err) {
          console.error(`Error watching for lock file deletion: ${err.message}`);
          watcher.close();
        }
      });
    });
  }
  async release() {
    try {
      if ((0, _fs.existsSync)(this.lockFilePath)) {
        (0, _fs.unlinkSync)(this.lockFilePath);
        console.log(`Lock file deleted: ${this.lockFilePath}`);
      }
    } catch (err) {
      console.error(`Error deleting lock file: ${err.message}`);
    }
  }
  async createDirectoryIfNotExist() {
    if (!(0, _fs.existsSync)(this.directory)) {
      (0, _fs.mkdirSync)(this.directory, {
        recursive: true
      });
    }
  }
}
function _getLockFilePath2() {
  return _path.default.resolve(_path.default.join(this.directory, this.lockFileName));
}
var _default = exports.default = FileMutex;